const config = {
  parser: 'babel-eslint',
  parserOptions: {
    ecmaVersion: 2017,
    sourceType: 'module',
    ecmaFeatures: {
      experimentalObjectRestSpread: true,
      generators: true,
      jsx: true,
    },
  },

  extends: [
    'eslint:recommended',
    'plugin:jest/recommended',
    'plugin:jsx-a11y/recommended',
    'plugin:react/recommended',
    'airbnb',
    'plugin:flowtype/recommended',
  ],

  settings: {
    'import/ignore': ['node_modules'],
    'import/extensions': ['.js', '.json'],
  },

  plugins: [
    'flowtype',
    'flowtype-errors',
    'jest',
    'jsx-a11y',
    'import',
    'node',
    'promise',
    'react',
    'standard',
  ],

  rules: {
    'no-console': 'off',
    'no-confusing-arrow': 'off',
    'no-multiple-empty-lines': ['warn', { max: 3, maxEOF: 0 }],
    'no-unreachable': 'warn',
    'no-unused-expressions': ['warn', { allowShortCircuit: true, allowTernary: true, allowTaggedTemplates: true }],
    'no-useless-computed-key': 'warn',
    'no-useless-constructor': 'warn',
    'no-useless-rename': ['warn', { ignoreDestructuring: false, ignoreImport: false, ignoreExport: false }],
    'padded-blocks': ['warn', { blocks: 'never', switches: 'never', classes: 'never' }],
    'prefer-const': 'warn',
    'semi': ['warn', 'always'],
    'semi-spacing': ['warn', { before: false, after: true }],

    'import/default': 'warn',
    'import/named': 'warn',
    'import/namespace': 'warn',
    'import/extensions': ['warn', 'never'],

    'jsx-a11y/aria-props': 'warn',
    'jsx-a11y/heading-has-content': 'warn',
    'jsx-a11y/label-has-for': 'warn',
    'jsx-a11y/mouse-events-have-key-events': 'warn',
    'jsx-a11y/aria-role': 'warn',
    'jsx-a11y/role-has-required-aria-props': 'warn',
    'jsx-a11y/role-supports-aria-props': 'warn',
    'jsx-a11y/img-redundant-alt': 'warn',
    'jsx-a11y/no-access-key': 'warn',
    'jsx-a11y/href-no-hash': ['off', { components: ['a'] }],

    'node/no-deprecated-api': 'warn',
    'node/process-exit-as-throw': 'warn',

    'promise/param-names': 'warn',

    'react/forbid-prop-types': 'off',
    'react/jsx-filename-extension': ['warn', { fileNames: ['.js'] }],

    'flowtype/define-flow-type': 'warn',
    'flowtype/require-valid-file-annotation': 'warn',
    'flowtype/use-flow-type': 'warn',

    "flowtype-errors/show-errors": "error"
  },
};

module.exports = config;
